@@ -37,8 +37,14 @@
 #define HCF_VERBOSE 0
 #define WORDLENGTH 28 	//length used to chop bitsets into words
 
-using namespace std;
-
+using std::cerr;
+using std::endl;
+using std::istream;
+using std::list;
+using std::map;
+using std::ostream;
+using std::string;
+using std::vector;
 
 /**
  * @brief Trait coefficient for a set of loci.
@@ -226,8 +232,6 @@ struct clone_t {
 #include <list>
 #include <gsl/gsl_histogram.h>
 
-using namespace std;
-
 struct tree_key_t {
 	int index;
 	int age;
@@ -337,6 +341,8 @@ public:
         // construct subtrees
 	int construct_subtree(vector <tree_key_t> subtree_leafs, rooted_tree &other);
 
+	vector <tree_key_t> get_sampled_leafs() const { return sampled_leafs; }
+	void set_sampled_leafs(const vector <tree_key_t>& leafs) { sampled_leafs = leafs; }
 private:
 	static int parse_label(std::string label, int *index, int *clone_size, int *branch_length);
 	int parse_subtree(tree_key_t &parent_key, std::string &tree_s);
